#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.contrib.operators.gcs_list_operator import GoogleCloudStorageListOperator
from airflow.operators.bash_operator import BashOperator

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
gcs_list_operator.py는 GCS에서 지정한 버킷 안에 존재하는 파일 등의 객체를 나열하는 DAG다.
"""


# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='gcs_list_operator',
    default_args=default_args,
    schedule_interval='@once',
)

# ‘table_’이라는 접두사 및 확장자가 .csv인 파일명을 취득한다.
get_list = GoogleCloudStorageListOperator(
    task_id='get_list',
    bucket='composer_source',
    prefix='table_',
    delimiter='.csv',
    dag=dag
)

# 취득한 파일명 리스트를 표시한다.
print_list = BashOperator(
    task_id='print_list',
    bash_command='echo "{{ti.xcom_pull(task_ids="get_list")}}"',
    dag=dag)

get_list >> print_list